@@ -10,12 +10,13 @@
 #ifndef SUMMARYWIDGET_H
 #define SUMMARYWIDGET_H
 
-#include <KontactInterface/Summary>
 #include <Akonadi/Calendar/ETMCalendar>
+#include <KontactInterface/Summary>
 
 class KOrganizerPlugin;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Item;
 class IncidenceChanger;
 }
@@ -41,7 +42,7 @@ public:
     void configUpdated();
     void updateSummary(bool force = false) override
     {
-        Q_UNUSED(force);
+        Q_UNUSED(force)
         updateView();
     }
 
