@@ -16,11 +16,13 @@
 
 class CalendarView;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Item;
 }
 
-namespace KParts {
+namespace KParts
+{
 class StatusBarExtension;
 }
 
@@ -28,7 +30,7 @@ class KOrganizerPart : public KParts::ReadOnlyPart, public KOrg::MainWindow
 {
     Q_OBJECT
 public:
-    KOrganizerPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
+    explicit KOrganizerPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
     ~KOrganizerPart() override;
 
     KOrg::CalendarViewBase *view() const override;
